// Converts a JavaScript date into a SQL date (stripping out the time)
function dbdate(dt)
{
	return (dt.getMonth() + 1) + "/" +
		dt.getDate() + "/" +
		(1900 + dt.getYear())
}

// Formats a phone number nicely
function formatphone(num)
{
	var newnum = "";

	// Strip out any non-numerical chars (except for "x" for extension)
	for (var i = 0; i < num.length; i++)
		if ("1234567890x".indexOf(num.charAt(i)) != -1)
			newnum = newnum + num.charAt(i);

	// If string is empty, nothing to do
	if (newnum == "")
		return "";

	// Separate the extension number, if any
	var extnum = "";
	if (newnum.indexOf("x") != -1)
	{
		extnum = newnum.substring(newnum.indexOf("x"), newnum.length);
		newnum = newnum.substring(0, newnum.indexOf("x"));
	}

	// Ditch a blank extension (lonely "x")
	if (extnum == "x")
		extnum = "";

	// Seven digit phone number (###-####[x###])
	if (newnum.length == 7)
		return newnum.substring(0, 3) + "-" + newnum.substring(3, 7) +
			extnum;
	// Ten digit phone number (###-###-####[x###])
	else if (newnum.length == 10)
		return newnum.substring(0, 3) + "-" + newnum.substring(3, 6) + 
			"-" + newnum.substring(6, 10) + extnum;
	// Non-standard so leave alone
	else
		return newnum + extnum;
}

// Finds an unused id for a given table and field from the database
function getNewID(table, fieldID)
{
	var newID = 1;

	// Check to see if the table is empty
	var count = database.cursor("select count(*) numid from " +
		table);
	count.next();

	// If it's not...
	if (count.numid > "0")
	{
		// Get the maximum id and add one, creating a new id
		var max = database.cursor("select max(" + fieldID +
			") id from " + table);
		if (max.next())
			newID = max.id + 1;

		max.close();
	}
	count.close();

	return newID;
}

// Doubles the single quotes in a string to make SQL happy
function sqlescape(str)
{
	var newstr = str;
	var quotepos = newstr.indexOf("'");

	// Nothing to do?
	if (newstr.length == 0)
		return "";

	// As long as there still are quotes...
	while (quotepos != -1)
	{
		// Are we at the end of the string?
		if (quotepos == newstr.length - 1)
		{
			// Stick a quote on and stop
			newstr = newstr + "'";
			quotepos = -1;
		}
		else
		{
			// Stick a quote in the middle and try to find another 
			newstr = newstr.substring(0, quotepos + 1) + "'" +
				newstr.substring(quotepos + 1, newstr.length);
			quotepos = newstr.indexOf("'", quotepos + 2);
		}
	}

	return newstr;
}

// Trims the spaces from a string
function trim(param)
{
	var str = "" + param;
	var result;

	// Find the first non-space character
	for (var i = 0; i < str.length; i++)
		if (str.charAt(i) != ' ')
			break;

	// Get rid of the leading spaces
	result = str.substring(i);	

	// Find the last non-space character
	for (i = result.length - 1; i >= 0; i--)
		if (result.charAt(i) != ' ')
			break;

	// Get rid of the trailing spaces
	result = result.substring(0, i + 1);

	return result;
}
